@@ -11,16 +11,7 @@
 # vim: tabstop=2 expandtab shiftwidth=2 softtabstop=2 smarttab
 
 class OneException(Exception):
-  def __init__(self, message):
-    self.message = message
-
-  def _get_message(self):
-    return self._message
-
-  def _set_message(self, message):
-    self._message = message
-
-  message = property(_get_message, _set_message)
+  pass
 
 class OnePlatformException(OneException):
   pass
